StreamThumbnailWeb class
A web implementation of the StreamThumbnailPlatform.
- Inheritance
-
- Object
- PlatformInterface
- StreamThumbnailWeb
Constructors
- StreamThumbnailWeb()
- Constructs a StreamThumbnailWeb.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
thumbnailData(
{required String video, required Map< String, String> ? headers, required StreamThumbnailFormat imageFormat, required int maxHeight, required int maxWidth, int? timeMs, required int quality}) → Future<Uint8List> -
Generates a thumbnail for the given
videoas in-memory bytes. -
thumbnailFile(
{required String video, required Map< String, String> ? headers, required String? thumbnailPath, required StreamThumbnailFormat imageFormat, required int maxHeight, required int maxWidth, int? timeMs, required int quality}) → Future<XFile> -
Generates a thumbnail file for the given
video. -
thumbnailFiles(
{required List< String> videos, required Map<String, String> ? headers, required String? thumbnailPath, required StreamThumbnailFormat imageFormat, required int maxHeight, required int maxWidth, int? timeMs, required int quality}) → Future<List< XFile> > -
Generates a thumbnail file for each of the given
videos. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void -
Registers this class as the default
StreamThumbnailPlatformon web.